====
List
====

The following methods are available under the `expr.list` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.list.all
    Expr.list.any
    Expr.list.arg_max
    Expr.list.arg_min
    Expr.list.concat
    Expr.list.contains
    Expr.list.count_matches
    Expr.list.diff
    Expr.list.drop_nulls
    Expr.list.eval
    Expr.list.explode
    Expr.list.filter
    Expr.list.first
    Expr.list.gather
    Expr.list.gather_every
    Expr.list.get
    Expr.list.head
    Expr.list.join
    Expr.list.last
    Expr.list.len
    Expr.list.max
    Expr.list.mean
    Expr.list.median
    Expr.list.min
    Expr.list.n_unique
    Expr.list.reverse
    Expr.list.sample
    Expr.list.set_difference
    Expr.list.set_intersection
    Expr.list.set_symmetric_difference
    Expr.list.set_union
    Expr.list.shift
    Expr.list.slice
    Expr.list.sort
    Expr.list.std
    Expr.list.sum
    Expr.list.tail
    Expr.list.to_array
    Expr.list.to_struct
    Expr.list.unique
    Expr.list.var
